import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const xValue = (d) => d.Budget;
const yValue = (d) => d.Movies;
const margin = {
  top: 80, // Adjusted to give more space for the title
  right: 30,
  bottom: 70,
  left: 220,
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const render = (data) => {
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.3);

  const xAxisTickFormat = (number) =>
    format('.2s')(number).replace('G', 'B');

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  g.append('g')
    .call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
    .remove();

  const xAxisG = g
    .append('g')
    .call(
      axisBottom(xScale)
        .tickFormat(xAxisTickFormat)
        .tickSize(-innerHeight),
    )
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', innerWidth / 2)
    .attr('y', margin.bottom - 10)
    .attr('fill', 'Purple')
    .text('Production Budget');

  g.selectAll('.bar')
    .data(data)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', (d) => xScale(xValue(d)))
    .attr('height', yScale.bandwidth());

  g.append('text')
    .attr('class', 'axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 30)
    .attr('x', -(innerHeight / 2))
    .attr('text-anchor', 'middle')
    .attr('fill', 'Purple')
    .text('Movies');

  // Adding the title "Movies with Their Budget"
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top / 2) // Position the title within the top margin area
    .attr('text-anchor', 'middle')
    .attr('fill', 'green')
    .attr('class', 'graph-title')
    .style('font-size', '24px')
    .text('INDIAN MOVIES WITH THEIR BUDGET IN MILLIONS');
};

csv('data.csv').then((data) => {
  data.forEach((d) => {
    d.Budget = +d.Budget;
  });
  render(data);
});
